@@ -13,3 +13,10 @@ def contains_only_digits(StrValue):
     else: 
        return   'FAIL'
 
+def Format_Validator(FieldFormat, FieldValue): 
+    Regex_Match = re.match(FieldFormat, FieldValue)
+    if Regex_Match: 
+       return    Regex_Match
+    else: 
+       return    'FAIL'
+
